# ModelWithPositioningPlan

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**translation_x** | **float** |  | [optional] 
**translation_y** | **float** |  | [optional] 
**rotate_z** | **float** |  | [optional] 
**scale** | **float** |  | [optional] 
**opacity** | **float** |  | [optional] 
**plan** | [**Model**](Model.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


